@@ -32,9 +32,9 @@ using namespace KCalendarCore;
 
 #include <KHolidays/HolidayRegion>
 using namespace KHolidays;
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 
-#include <QtTest>
+#include <QTest>
 
 QTEST_GUILESS_MAIN(KAEventTest)
 
